
#!/bin/sh


linkDir="/dev/ubi"
sysLinkDir="/dev/ubi/sysfs"

if [ -z "${ACTION}" ]; then
    ACTION="add"
fi

logger -t $0 -p 6 "Ubi volume change detected!"
logger -t $0 -p 6 "MDEV:        $MDEV"
logger -t $0 -p 6 "DEVPATH:     $DEVPATH"

case "${ACTION}" in
    remove)
        # Find broken links and delete them
        for file in $(find ${linkDir} -type l); do
            if [ ! -r ${file} ]; then
                logger -t $0 -p 6 "Removing link ${file}"
                rm ${file}
            fi
        done

        for file in $(find ${sysLinkDir} -type l); do
            if [ ! -r ${file} ]; then
                logger -t $0 -p 6 "Removing link ${file}"
                rm ${file}
            fi
        done

        ;;
    add)
        # Make sure linkdir exists
	mkdir -p ${sysLinkDir}
        
        # Get the ubi volume name which was added
	name=$(ubinfo /dev/${MDEV} | awk '/^Name/ { print $2 }')
	logger -t $0 -p 6 "NAME:        $name"
                                         
        # Create link in /dev/ubi/UBINAME and /dev/ubi/sysfs/UBINAME
	# Sysfs is a directory used to read information from the devices
        logger -t $0 -p 6 "Creating link ${linkDir}/${name} to /dev/${MDEV}"
        ln -s /dev/${MDEV} ${linkDir}/${name} 
	  
	logger -t $0 -p 6 "Creating link ${sysLinkDir}/${name} to /sys/class/${MDEV}"
        ln -s /sys/class/ubi/${MDEV} ${sysLinkDir}/${name} 

        ;;
    *)
        exit 1
esac

exit $?
